pub struct IncludeSet(/* private fields */);Expand description
Regex patterns used to include only matching words.
Examples
use word_tally::IncludeSet;
// Create a pattern to include only words containing vowels.
let patterns = IncludeSet::new(vec![r"[aeiou]".to_string()]).unwrap();
// Test matching
assert!(patterns.matches("test")); // Contains 'e'
assert!(!patterns.matches("rhythm")); // No vowelsImplementations
Sourceimpl IncludeSet
impl IncludeSet
Sourcepub fn new(input_patterns: PatternList) -> Result<Self, WordTallyError>
pub fn new(input_patterns: PatternList) -> Result<Self, WordTallyError>
Creates patterns from owned pattern strings.
Examples
use word_tally::IncludeSet;
// Create patterns for including words with specific prefixes.
let patterns = IncludeSet::new(vec![r"^pre".to_string(), r"^un".to_string()]).unwrap();
assert_eq!(patterns.len(), 2);
assert!(patterns.matches("prevent"));
assert!(patterns.matches("unlike"));
assert!(!patterns.matches("likely"));Errors
Returns an error if any pattern cannot be compiled into a valid regular expression.
Sourcepub fn as_patterns(&self) -> &[String]
pub fn as_patterns(&self) -> &[String]
Returns a slice of the original pattern strings.