pub enum Serialization {
Text(Delimiters),
Json,
Csv,
}Expand description
Serialization format options.
Variants
Implementations
Sourceimpl Serialization
impl Serialization
Sourcepub fn field_delimiter_display(&self) -> String
pub fn field_delimiter_display(&self) -> String
Get the field delimiter formatted for display, or “n/a” if not text format.
Sourcepub fn entry_delimiter_display(&self) -> String
pub fn entry_delimiter_display(&self) -> String
Get the entry delimiter formatted for display, or “n/a” if not text format.